@@ -19,8 +19,8 @@ def install(user=False, symlink=False, **kwargs):
     **kwargs: keyword arguments
         Other keyword arguments passed to the install_nbextension command
     """
-    dir = join(dirname(abspath(__file__)), 'nbextension')
-    install_nbextension(gamepad, destination='pythreejs',
+    directory = join(dirname(abspath(__file__)), 'nbextension')
+    install_nbextension(directory, destination='pythreejs',
                         symlink=symlink, user=user, **kwargs)
 
     
@@ -32,5 +32,8 @@ if __name__ == '__main__':
     parser.add_argument("-s", "--symlink",
                         help="Symlink instead of copying files",
                         action="store_true")
+    parser.add_argument("-f", "--force",
+                        help="Overwrite any previously-installed files for this extension",
+                        action="store_true")
     args = parser.parse_args()
-    install(user=args.user, symlink=args.symlink)
\ No newline at end of file
+    install(user=args.user, symlink=args.symlink, overwrite=args.force)
